@@ -40,14 +40,13 @@
  ***********************************************************/
 
 #include <stdio.h>
-#include "translate.h"
 #include "motion.h"
+#include "translate.h"
 #include "util.h"
 #include "logger.h"
 #include "rotate.h"
 #include "netcam.h"
 #include "netcam_rtsp.h"
-#include "video_v4l2.h"  /* Needed to validate palette for v4l2 via netcam */
 
 #ifdef HAVE_FFMPEG
 
@@ -355,7 +354,6 @@ static int netcam_decode_vaapi(struct rtsp_context *rtsp_data)
             my_frame_free(hw_frame);
             return retcd;
         }
-        rtsp_data->frame->format=AV_PIX_FMT_YUV420P;
 
         retcd = av_hwframe_transfer_data(rtsp_data->frame, hw_frame, 0);
         if (retcd < 0) {
@@ -427,6 +425,58 @@ static int netcam_decode_cuda(struct rtsp_context *rtsp_data)
     #endif
 }
 
+static int netcam_decode_drm(struct rtsp_context *rtsp_data)
+{
+
+    #if ( MYFFVER >= 57083)
+
+        int retcd;
+        char errstr[128];
+        AVFrame *hw_frame = NULL;
+
+        hw_frame = my_frame_alloc();
+
+        retcd = avcodec_receive_frame(rtsp_data->codec_context, hw_frame);
+        if ((rtsp_data->interrupted) || (rtsp_data->finish) || (retcd < 0) ){
+            if (retcd == AVERROR(EAGAIN)){
+                retcd = 0;
+            } else if (retcd == AVERROR_INVALIDDATA) {
+                MOTION_LOG(INF, TYPE_NETCAM, NO_ERRNO
+                    ,_("%s: Ignoring packet with invalid data")
+                    ,rtsp_data->cameratype);
+                retcd = 0;
+            } else if (retcd < 0) {
+                av_strerror(retcd, errstr, sizeof(errstr));
+                    MOTION_LOG(INF, TYPE_NETCAM, NO_ERRNO
+                        ,_("%s: Rec frame error: %s")
+                        ,rtsp_data->cameratype, errstr);
+                retcd = -1;
+            } else {
+                retcd = -1;
+            }
+            my_frame_free(hw_frame);
+            return retcd;
+        }
+        rtsp_data->frame->format=AV_PIX_FMT_NV12;
+
+        retcd = av_hwframe_transfer_data(rtsp_data->frame, hw_frame, 0);
+        if (retcd < 0) {
+            MOTION_LOG(INF, TYPE_NETCAM, NO_ERRNO
+                ,_("%s: Error transferring HW decoded to system memory")
+                ,rtsp_data->cameratype);
+            my_frame_free(hw_frame);
+            return -1;
+        }
+
+        my_frame_free(hw_frame);
+
+        return 1;
+    #else
+        (void)rtsp_data;
+        return 1;
+    #endif
+}
+
 /* netcam_rtsp_decode_video
  *
  * Return values:
@@ -465,13 +515,20 @@ static int netcam_rtsp_decode_video(struct rtsp_context *rtsp_data)
             av_strerror(retcd, errstr, sizeof(errstr));
             MOTION_LOG(INF, TYPE_NETCAM, NO_ERRNO
                 ,_("Error sending packet to codec: %s"), errstr);
-            return -1;
+            /* This is non fatal for file processing */
+            if (mystreq(rtsp_data->service, "file")) {
+                return 0;
+            } else {
+                return -1;
+            }
         }
 
         if (mystrceq(rtsp_data->decoder_nm,"vaapi")) {
             retcd = netcam_decode_vaapi(rtsp_data);
         } else if (mystrceq(rtsp_data->decoder_nm,"cuda")) {
             retcd = netcam_decode_cuda(rtsp_data);
+        } else if (mystrceq(rtsp_data->decoder_nm,"drm")) {
+            retcd = netcam_decode_drm(rtsp_data);
         } else {
             retcd = netcam_decode_sw(rtsp_data);
         }
@@ -555,7 +612,7 @@ static void netcam_hwdecoders(struct rtsp_context *rtsp_data)
                 ,_("%s: HW Devices: ")
                 , rtsp_data->cameratype);
             while((rtsp_data->hw_type = av_hwdevice_iterate_types(rtsp_data->hw_type)) != AV_HWDEVICE_TYPE_NONE){
-                if (rtsp_data->hw_type == AV_HWDEVICE_TYPE_VAAPI || rtsp_data->hw_type == AV_HWDEVICE_TYPE_CUDA) {
+                if (rtsp_data->hw_type == AV_HWDEVICE_TYPE_VAAPI || rtsp_data->hw_type == AV_HWDEVICE_TYPE_CUDA || rtsp_data->hw_type == AV_HWDEVICE_TYPE_DRM) {
                     MOTION_LOG(INF, TYPE_NETCAM, NO_ERRNO
                         ,_("%s: %s (available)")
                         , rtsp_data->cameratype
@@ -624,6 +681,26 @@ static enum AVPixelFormat netcam_getfmt_cuda(AVCodecContext *avctx, const enum A
     #endif
 }
 
+static enum AVPixelFormat netcam_getfmt_drm(AVCodecContext *avctx, const enum AVPixelFormat *pix_fmts)
+{
+    #if ( MYFFVER >= 57083)
+        const enum AVPixelFormat *p;
+        (void)avctx;
+
+        for (p = pix_fmts; *p != -1; p++) {
+            if (*p == AV_PIX_FMT_DRM_PRIME) return *p;
+        }
+
+        MOTION_LOG(ERR, TYPE_NETCAM, NO_ERRNO,_("Failed to get drm pix format"));
+        return AV_PIX_FMT_NONE;
+    #else
+        (void)avctx;
+        (void)pix_fmts;
+        return AV_PIX_FMT_NONE;
+    #endif
+}
+
+
 static void netcam_rtsp_decoder_error(struct rtsp_context *rtsp_data, int retcd, const char* fnc_nm)
 {
 
@@ -781,6 +858,59 @@ static int netcam_init_cuda(struct rtsp_context *rtsp_data)
     #endif
 }
 
+static int netcam_init_drm(struct rtsp_context *rtsp_data)
+{
+
+    #if ( MYFFVER >= 57083)
+
+        int retcd;
+
+        MOTION_LOG(INF, TYPE_NETCAM, NO_ERRNO
+            ,_("%s: Initializing drm decoder"),rtsp_data->cameratype);
+
+        rtsp_data->hw_type = av_hwdevice_find_type_by_name("drm");
+        if (rtsp_data->hw_type == AV_HWDEVICE_TYPE_NONE){
+            MOTION_LOG(ERR, TYPE_NETCAM, NO_ERRNO,_("%s: Unable to find drm hw device")
+                , rtsp_data->cameratype);
+            netcam_rtsp_decoder_error(rtsp_data, 0, "av_hwdevice");
+            return -1;
+        }
+
+        rtsp_data->codec_context = avcodec_alloc_context3(rtsp_data->decoder);
+        if ((rtsp_data->codec_context == NULL) || (rtsp_data->interrupted)){
+            netcam_rtsp_decoder_error(rtsp_data, 0, "avcodec_alloc_context3");
+            return -1;
+        }
+
+        retcd = avcodec_parameters_to_context(rtsp_data->codec_context,rtsp_data->strm->codecpar);
+        if ((retcd < 0) || (rtsp_data->interrupted)) {
+            netcam_rtsp_decoder_error(rtsp_data, retcd, "avcodec_parameters_to_context");
+            return -1;
+        }
+
+        rtsp_data->hw_pix_fmt = AV_PIX_FMT_DRM_PRIME;
+        rtsp_data->codec_context->get_format  = netcam_getfmt_drm;
+        av_opt_set_int(rtsp_data->codec_context, "refcounted_frames", 1, 0);
+        rtsp_data->codec_context->sw_pix_fmt = AV_PIX_FMT_YUV420P;
+        rtsp_data->codec_context->hwaccel_flags=
+            AV_HWACCEL_FLAG_ALLOW_PROFILE_MISMATCH |
+            AV_HWACCEL_FLAG_IGNORE_LEVEL;
+
+        retcd = av_hwdevice_ctx_create(&rtsp_data->hw_device_ctx, rtsp_data->hw_type, NULL, NULL, 0);
+        if (retcd < 0){
+            netcam_rtsp_decoder_error(rtsp_data, retcd, "hwctx");
+            return -1;
+        }
+        rtsp_data->codec_context->hw_device_ctx = av_buffer_ref(rtsp_data->hw_device_ctx);
+
+        return 0;
+    #else
+        (void)rtsp_data;
+        (void)netcam_getfmt_drm;
+        return 0;
+    #endif
+}
+
 static int netcam_init_swdecoder(struct rtsp_context *rtsp_data)
 {
 
@@ -868,6 +998,8 @@ static int netcam_rtsp_open_codec(struct rtsp_context *rtsp_data)
             retcd = netcam_init_vaapi(rtsp_data);
         } else if (mystrceq(rtsp_data->decoder_nm,"cuda")){
             retcd = netcam_init_cuda(rtsp_data);
+	} else if (mystrceq(rtsp_data->decoder_nm,"drm")){
+            retcd = netcam_init_drm(rtsp_data);
         } else {
             retcd = netcam_init_swdecoder(rtsp_data);
         }
@@ -1341,12 +1473,16 @@ static void netcam_rtsp_set_options(struct rtsp_context *rtsp_data)
         MOTION_LOG(INF, TYPE_NETCAM, NO_ERRNO,_("%s: Setting rtsp/rtmp")
             ,rtsp_data->cameratype);
         util_parms_add_default(rtsp_data->parameters,"rtsp_transport","tcp");
-        util_parms_add_default(rtsp_data->parameters,"allowed_media_types", "video");
 
     } else if (strncmp(rtsp_data->service, "http", 4) == 0 ) {
         MOTION_LOG(INF, TYPE_NETCAM, NO_ERRNO
             ,_("%s: Setting input_format mjpeg"),rtsp_data->cameratype);
         rtsp_data->format_context->iformat = av_find_input_format("mjpeg");
+        util_parms_add_default(rtsp_data->parameters,"reconnect_on_network_error","1");
+        util_parms_add_default(rtsp_data->parameters,"reconnect_at_eof","1");
+        util_parms_add_default(rtsp_data->parameters,"reconnect","1");
+        util_parms_add_default(rtsp_data->parameters,"multiple_requests","1");
+        util_parms_add_default(rtsp_data->parameters,"reconnect_streamed","1");
 
     } else if (strncmp(rtsp_data->service, "v4l2", 4) == 0 ) {
         MOTION_LOG(INF, TYPE_NETCAM, NO_ERRNO
@@ -2163,7 +2299,7 @@ int netcam_rtsp_next(struct context *cnt, struct image_data *img_data)
             }
             pthread_mutex_lock(&cnt->rtsp_high->mutex);
                 netcam_rtsp_pktarray_resize(cnt, TRUE);
-                if (!(cnt->rtsp_high->high_resolution && cnt->rtsp_high->passthrough)) {
+                if (!cnt->rtsp_high->passthrough) {
                     memcpy(img_data->image_high
                         ,cnt->rtsp_high->img_latest->ptr
                         ,cnt->rtsp_high->img_latest->used);
@@ -2269,3 +2405,4 @@ void netcam_rtsp_cleanup(struct context *cnt, int init_retry_flag)
 
 }
 
+
